<?php
namespace Bushelpowered\Api\Payments\V1\Model;
        
class PaymentDetail 
{
    /** @var string $id The primary unique identifier.*/
    public string $id;
    /** @var string $item A human readable name that will briefly describe this payment*/
    public string $item;
    /** @var string $amount The amount of this payment*/
    public string $amount;
    /** @var \Bushelpowered\Api\Payments\V1\Enums\PaymentStatus $status */
    public \Bushelpowered\Api\Payments\V1\Enums\PaymentStatus $status;
    /** @var null|string $comments The person making the payment can say anything that they want to about the payment. Required for one time payments*/
    public ?string $comments = null;
    /** @var string $counterPartyUserName The party on the other side of the transaction.*/
    public string $counterPartyUserName;
    /** @var \Bushelpowered\Api\Payments\V1\Enums\PaymentEntry $entry */
    public \Bushelpowered\Api\Payments\V1\Enums\PaymentEntry $entry;
    /** @var null|\Bushelpowered\Api\Payments\V1\Enums\CardType $cardType */
    public ?\Bushelpowered\Api\Payments\V1\Enums\CardType $cardType = null;
    /** @var null|string $cardBrand Card payments only: The brand of card that was used*/
    public ?string $cardBrand = null;
    /** @var null|string $cardLast4 Card payments only: The last 4 numbers of the card that was used*/
    public ?string $cardLast4 = null;
    /** @var null|string $processedAt When the payment process was started of RFC-3339 format, IE: 2023-10-04T21:26:22+00:00*/
    public ?string $processedAt = null;
    /** @var null|string $completedAt When the payment process was completed of RFC-3339 format, IE: 2023-10-04T21:26:22+00:00*/
    public ?string $completedAt = null;
    /** @var string $updatedAt When the payment was last updated of RFC-3339 format, IE: 2023-10-04T21:26:22+00:00*/
    public string $updatedAt;
    /** @var \Bushelpowered\Api\Payments\V1\Model\SettlementAssociation[] $settlements Associated settlements*/
    public array $settlements;
    /** @var \Bushelpowered\Api\Payments\V1\Model\InvoiceAssociation[] $invoices Associated invoices*/
    public array $invoices;

    /**
     * @param  string  $id The primary unique identifier.
     * @param  string  $item A human readable name that will briefly describe this payment
     * @param  string  $amount The amount of this payment
     * @param  \Bushelpowered\Api\Payments\V1\Enums\PaymentStatus  $status 
     * @param  null|string  $comments The person making the payment can say anything that they want to about the payment. Required for one time payments
     * @param  string  $counterPartyUserName The party on the other side of the transaction.
     * @param  \Bushelpowered\Api\Payments\V1\Enums\PaymentEntry  $entry 
     * @param  null|\Bushelpowered\Api\Payments\V1\Enums\CardType  $cardType 
     * @param  null|string  $cardBrand Card payments only: The brand of card that was used
     * @param  null|string  $cardLast4 Card payments only: The last 4 numbers of the card that was used
     * @param  null|string  $processedAt When the payment process was started of RFC-3339 format, IE: 2023-10-04T21:26:22+00:00
     * @param  null|string  $completedAt When the payment process was completed of RFC-3339 format, IE: 2023-10-04T21:26:22+00:00
     * @param  string  $updatedAt When the payment was last updated of RFC-3339 format, IE: 2023-10-04T21:26:22+00:00
     * @param  \Bushelpowered\Api\Payments\V1\Model\SettlementAssociation[]  $settlements Associated settlements
     * @param  \Bushelpowered\Api\Payments\V1\Model\InvoiceAssociation[]  $invoices Associated invoices
     */
    public function __construct(string $id, string $item, string $amount, \Bushelpowered\Api\Payments\V1\Enums\PaymentStatus $status, ?string $comments, string $counterPartyUserName, \Bushelpowered\Api\Payments\V1\Enums\PaymentEntry $entry, ?\Bushelpowered\Api\Payments\V1\Enums\CardType $cardType, ?string $cardBrand, ?string $cardLast4, ?string $processedAt, ?string $completedAt, string $updatedAt, array $settlements, array $invoices)
    {
        $this->id = $id;
        $this->item = $item;
        $this->amount = $amount;
        $this->status = $status;
        $this->comments = $comments;
        $this->counterPartyUserName = $counterPartyUserName;
        $this->entry = $entry;
        $this->cardType = $cardType;
        $this->cardBrand = $cardBrand;
        $this->cardLast4 = $cardLast4;
        $this->processedAt = $processedAt;
        $this->completedAt = $completedAt;
        $this->updatedAt = $updatedAt;
        $this->settlements = $settlements;
        $this->invoices = $invoices;
    }
    

}