<?php
namespace Bushelpowered\Api\Platform\Authorization\V1\Model;
        
class IdentifierAccount implements \Bushelpowered\Api\Common\HasTimestamps
{
    /** @var string $tenantId The id of the tenant this record belongs to.*/
    public string $tenantId;
    /** @var string $datasourceId The id of the datasource this record came from.*/
    public string $datasourceId;
    /** @var string $integrationId The unique identifier for this record, concatenation of identifierIntegrationId and accountIntegrationId*/
    public string $integrationId;
    /** @var string $idpSlug The slug that specifies which identity provider should be used to authenticate this account binding.*/
    public string $idpSlug;
    /** @var string $userIdpId The identifier for the user in the specified IDP.*/
    public string $userIdpId;
    /** @var string $identifierIntegrationId The global unique identifier of the source record, often concatenation of the datasource and source identifiers to ensure uniqueness.*/
    public string $identifierIntegrationId;
    /** @var null|string $identifierName The name specified for the owner of the identifier.*/
    public ?string $identifierName = null;
    /** @var string $accountId The id of the account.*/
    public string $accountId;
    /** @var string $accountIntegrationId The account integration identifier.*/
    public string $accountIntegrationId;
    /** @var string $sourceAccountId The Id of the account in the remote system.*/
    public string $sourceAccountId;
    /** @var string $createdAt Created date-time within the microservice. of RFC-3339 format, IE: 2023-10-04T21:26:22+00:00*/
    public string $createdAt;
    /** @var string $updatedAt Updated date-time within the microservice. of RFC-3339 format, IE: 2023-10-04T21:26:22+00:00*/
    public string $updatedAt;
    /** @var null|string $deletedAt Deleted date-time within the microservice. of RFC-3339 format, IE: 2023-10-04T21:26:22+00:00*/
    public ?string $deletedAt = null;

    /**
     * @param  string  $tenantId The id of the tenant this record belongs to.
     * @param  string  $datasourceId The id of the datasource this record came from.
     * @param  string  $integrationId The unique identifier for this record, concatenation of identifierIntegrationId and accountIntegrationId
     * @param  string  $idpSlug The slug that specifies which identity provider should be used to authenticate this account binding.
     * @param  string  $userIdpId The identifier for the user in the specified IDP.
     * @param  string  $identifierIntegrationId The global unique identifier of the source record, often concatenation of the datasource and source identifiers to ensure uniqueness.
     * @param  null|string  $identifierName The name specified for the owner of the identifier.
     * @param  string  $accountId The id of the account.
     * @param  string  $accountIntegrationId The account integration identifier.
     * @param  string  $sourceAccountId The Id of the account in the remote system.
     * @param  string  $createdAt Created date-time within the microservice. of RFC-3339 format, IE: 2023-10-04T21:26:22+00:00
     * @param  string  $updatedAt Updated date-time within the microservice. of RFC-3339 format, IE: 2023-10-04T21:26:22+00:00
     * @param  null|string  $deletedAt Deleted date-time within the microservice. of RFC-3339 format, IE: 2023-10-04T21:26:22+00:00
     */
    public function __construct(string $tenantId, string $datasourceId, string $integrationId, string $idpSlug, string $userIdpId, string $identifierIntegrationId, ?string $identifierName, string $accountId, string $accountIntegrationId, string $sourceAccountId, string $createdAt, string $updatedAt, ?string $deletedAt)
    {
        $this->tenantId = $tenantId;
        $this->datasourceId = $datasourceId;
        $this->integrationId = $integrationId;
        $this->idpSlug = $idpSlug;
        $this->userIdpId = $userIdpId;
        $this->identifierIntegrationId = $identifierIntegrationId;
        $this->identifierName = $identifierName;
        $this->accountId = $accountId;
        $this->accountIntegrationId = $accountIntegrationId;
        $this->sourceAccountId = $sourceAccountId;
        $this->createdAt = $createdAt;
        $this->updatedAt = $updatedAt;
        $this->deletedAt = $deletedAt;
    }
    
    /**
     * @return string Created date-time within the microservice. of RFC-3339 format, IE: 2023-10-04T21:26:22+00:00
     */
    public function getCreatedAt(): string
    {
        return $this->createdAt;
    }
    /**
     * @return string Updated date-time within the microservice. of RFC-3339 format, IE: 2023-10-04T21:26:22+00:00
     */
    public function getUpdatedAt(): string
    {
        return $this->updatedAt;
    }
    /**
     * @return null|string Deleted date-time within the microservice. of RFC-3339 format, IE: 2023-10-04T21:26:22+00:00
     */
    public function getDeletedAt(): ?string
    {
        return $this->deletedAt;
    }
}