<?php
namespace Bushelpowered\Api\Quoting\V1\Request;
        
class UpdateQuoteRequest 
{
    /** @var string $id The primary unique identifier.*/
    public string $id;
    /** @var string $accountId The UUID of the account associated with the quote*/
    public string $accountId;
    /** @var string $name The name of the quote*/
    public string $name;
    /** @var null|string $commodityId The UUID of the commodity associated with the quote*/
    public ?string $commodityId = null;
    /** @var string $customerName The name of the customer associated with the quote*/
    public string $customerName;
    /** @var string $fieldNames The field names for the quote*/
    public string $fieldNames;
    /** @var null|int $area The acres/hectares for the quote*/
    public ?int $area = null;
    /** @var \Bushelpowered\Api\Quoting\V1\Enums\AreaUoM $areaUoM */
    public \Bushelpowered\Api\Quoting\V1\Enums\AreaUoM $areaUoM;
    /** @var null|int $cropYear The crop year of the quote*/
    public ?int $cropYear = null;
    /** @var string $customerComments The customer's comments for the quote*/
    public string $customerComments;
    /** @var string $creationDate The creation date of the quote of yyyy-MM-dd format, IE: 2023-10-04*/
    public string $creationDate;
    /** @var \Bushelpowered\Api\Quoting\V1\Request\UpsertLineItemRequest[] $lineItems */
    public array $lineItems;
    /** @var \Bushelpowered\Api\Quoting\V1\Request\UpsertServiceRequest[] $services */
    public array $services;

    /**
     * @param  string  $id The primary unique identifier.
     * @param  string  $accountId The UUID of the account associated with the quote
     * @param  string  $name The name of the quote
     * @param  null|string  $commodityId The UUID of the commodity associated with the quote
     * @param  string  $customerName The name of the customer associated with the quote
     * @param  string  $fieldNames The field names for the quote
     * @param  null|int  $area The acres/hectares for the quote
     * @param  \Bushelpowered\Api\Quoting\V1\Enums\AreaUoM  $areaUoM 
     * @param  null|int  $cropYear The crop year of the quote
     * @param  string  $customerComments The customer's comments for the quote
     * @param  string  $creationDate The creation date of the quote of yyyy-MM-dd format, IE: 2023-10-04
     * @param  \Bushelpowered\Api\Quoting\V1\Request\UpsertLineItemRequest[]  $lineItems 
     * @param  \Bushelpowered\Api\Quoting\V1\Request\UpsertServiceRequest[]  $services 
     */
    public function __construct(string $id, string $accountId, string $name, ?string $commodityId, string $customerName, string $fieldNames, ?int $area, \Bushelpowered\Api\Quoting\V1\Enums\AreaUoM $areaUoM, ?int $cropYear, string $customerComments, string $creationDate, array $lineItems, array $services)
    {
        $this->id = $id;
        $this->accountId = $accountId;
        $this->name = $name;
        $this->commodityId = $commodityId;
        $this->customerName = $customerName;
        $this->fieldNames = $fieldNames;
        $this->area = $area;
        $this->areaUoM = $areaUoM;
        $this->cropYear = $cropYear;
        $this->customerComments = $customerComments;
        $this->creationDate = $creationDate;
        $this->lineItems = $lineItems;
        $this->services = $services;
    }
    

}